<?php
/**
 * aipower functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package aipower
 */

 define( 'AIPOWER_THEME_DRI', get_template_directory() );
 define( 'AIPOWER_INC_DRI', get_template_directory() . '/inc/' );
 define( 'AIPOWER_THEME_URI', get_template_directory_uri() );
 define( 'AIPOWER_CSS_PATH', AIPOWER_THEME_URI . '/assets/css' );
 define( 'AIPOWER_JS_PATH', AIPOWER_THEME_URI . '/assets/js' );
 define( 'AIPOWER_IMG_PATH', AIPOWER_THEME_URI . '/assets/images' );
 define( 'AIPOWER_ADMIN_DRI', AIPOWER_THEME_DRI . '/admin' );

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function aipower_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on aipower, use a find and replace
		* to change 'aipower' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'aipower', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	add_image_size('aipower-img-size-1', 450, 450, true);
	add_image_size('aipower-img-size-2', 475, 235, true);
	add_image_size('aipower-img-size-3', 810, 367, true);
	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );
	remove_theme_support( 'widgets-block-editor' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	//Woocommerc
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'aipower' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'aipower_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

}
add_action( 'after_setup_theme', 'aipower_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function aipower_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'aipower_content_width', 640 );
}
add_action( 'after_setup_theme', 'aipower_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function aipower_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'aipower' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'aipower' ),
			'before_widget' => '<div id="%1$s" class="ai-siderbar-widget"><div class="headline ul-li-block %2$s">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Shop Siderbar', 'aipower' ),
			'id'            => 'shop-sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'aipower' ),
			'before_widget' => '<div id="%1$s" class="widget mt-30 %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget__title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'aipower_widgets_init' );



/**
 *Google Font Load 
 */
if ( ! function_exists( 'aipower_fonts_url' ) ) :
	
	function aipower_fonts_url() {
		$fonts_url     = '';
		$font_families = array();
		$subsets       = 'latin';
	
	
		if ( 'off' !== _x( 'on', 'DM Sans: on or off', 'aipower' ) ) {
			$font_families[] = 'DM Sans:400,400i,500,500i,700,700i';
		}
		if ( 'off' !== _x( 'on', 'Plus Jakarta Sans: on or off', 'aipower' ) ) {
			$font_families[] = 'Plus Jakarta Sans:200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i';
		}
	
		if ( $font_families ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}
	
		return esc_url_raw( $fonts_url );
	}
	endif;


/**
 * Enqueue scripts and styles.
 */
function aipower_scripts() {

	wp_enqueue_style( 'aipower-google-fonts', aipower_fonts_url(), array(), null );

	wp_enqueue_style( 'bootstrap', AIPOWER_CSS_PATH . '/bootstrap.min.css' );
	wp_enqueue_style( 'fontawesomes', AIPOWER_CSS_PATH . '/fontawesome.css' );
	wp_enqueue_style( 'a-animate', AIPOWER_CSS_PATH . '/animate.css' );
	wp_enqueue_style( 'flaticon_aipower', AIPOWER_CSS_PATH . '/flaticon_aipower.css' );
	wp_enqueue_style( 'aipower-global', AIPOWER_CSS_PATH . '/global.css' );
	wp_enqueue_style( 'aipower-swiper', AIPOWER_CSS_PATH . '/swiper.min.css' );
	wp_enqueue_style( 'magnific-popup', AIPOWER_CSS_PATH . '/magnific-popup.css' );
	wp_enqueue_style( 'aipower-style', AIPOWER_CSS_PATH . '/style.css' );

	if ( class_exists('WooCommerce') ) {
		wp_enqueue_style( 'woocommerce-style', get_template_directory_uri() . '/woocommerce/woocommerce.css' );
	}

	if (is_rtl()) {		
		wp_enqueue_style( 'aipower-rtl', AIPOWER_CSS_PATH . '/rtl.css' );
	}

	wp_enqueue_style( 'aipower-style', get_stylesheet_uri(), array() );


	wp_enqueue_script('masonry');
	wp_enqueue_script('jquery-ui-core');
	wp_enqueue_script( 'bootstrap', AIPOWER_JS_PATH . '/bootstrap.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'popper', AIPOWER_JS_PATH . '/popper.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'aipower-swiper', AIPOWER_JS_PATH . '/swiper.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'wow', AIPOWER_JS_PATH . '/wow.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'appear', AIPOWER_JS_PATH . '/appear.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'parallax', AIPOWER_JS_PATH . '/parallax.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'jarallax', AIPOWER_JS_PATH . '/jarallax.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'magnific-popup', AIPOWER_JS_PATH . '/jquery.magnific-popup.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'charming', AIPOWER_JS_PATH . '/charming.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'countdown', AIPOWER_JS_PATH . '/countdown.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'touchspin', AIPOWER_JS_PATH . '/touchspin.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'jquery-marquee', AIPOWER_JS_PATH . '/jquery.marquee.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'hover-revel', AIPOWER_JS_PATH . '/hover-revel.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'gsap', AIPOWER_JS_PATH . '/gsap.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'counterup', AIPOWER_JS_PATH . '/jquery.counterup.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'waypoints', AIPOWER_JS_PATH . '/waypoints.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'scroll-trigger', AIPOWER_JS_PATH . '/scroll-trigger.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'split-text', AIPOWER_JS_PATH . '/split-text.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'particles', AIPOWER_JS_PATH . '/particles.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'app', AIPOWER_JS_PATH . '/app.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'typer', AIPOWER_JS_PATH . '/typer.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'twin', AIPOWER_JS_PATH . '/twin.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'rbtools', AIPOWER_JS_PATH . '/rbtools.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'aipower-script', AIPOWER_JS_PATH . '/script.js', array('jquery'), time(), true );
	


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'aipower_scripts' );

/**
 * Implement the Custom Header feature.
 */
require AIPOWER_THEME_DRI . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require AIPOWER_THEME_DRI . '/inc/template-tags.php';

/**
 * Custom template tags for this theme.
 */
require AIPOWER_THEME_DRI . '/inc/class-wp-aipower-navwalker.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require AIPOWER_THEME_DRI . '/inc/template-functions.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require AIPOWER_THEME_DRI . '/inc/aipower-functions.php';

/**
 * Cs Fremwork Config
 */
require AIPOWER_THEME_DRI . '/inc/cs-framework-functions.php';

/**
 * Dynamic Style
 */
require AIPOWER_THEME_DRI . '/inc/dynamic-style.php';

/**
 * aipower Core Functions
 */
require AIPOWER_THEME_DRI . '/inc/aipower-helper-class.php';

/**
 * aipower Core Functions
 */
require AIPOWER_THEME_DRI . '/inc/admin/class-admin-dashboard.php';

/**
 * aipower Core Functions
 */
require AIPOWER_THEME_DRI . '/inc/admin/demo-import/functions.php';

/**
 * Customizer additions.
 */
require AIPOWER_THEME_DRI . '/inc/customizer.php';


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require AIPOWER_THEME_DRI . '/inc/jetpack.php';
}

/**
 * Remove Action Hook
 */

 function aipower_woo_theme_init(){
	$aipower_exlude_hooks = require AIPOWER_THEME_DRI . '/inc/remove_actions.php';
	foreach( $aipower_exlude_hooks as $k => $v )
	{
		foreach( $v as $value )
		remove_action( $k, $value[0], $value[1] );
	}

}
add_action( 'init', 'aipower_woo_theme_init');

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1717520845728';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        